Compare iPhone Models - Apple

# Compare iPhone models

Find the best iPhone for you

## Technical Specifications

Features
iPhone 15 Pro Max
iPhone 15 Pro
iPhone 15
iPhone SE
Display
6.7" Super Retina XDR
6.1" Super Retina XDR
6.1" Super Retina XDR
4.7" Retina HD
Chip
A17 Pro
A17 Pro
A16 Bionic
A15 Bionic
Memory
256GB, 512GB, 1TB
128GB, 256GB, 512GB, 1TB
128GB, 256GB, 512GB
64GB, 128GB, 256GB
Camera
48MP Main
48MP Main
48MP Main
12MP Wide
Battery Life
Up to 29 hours video
Up to 23 hours video
Up to 20 hours video
Up to 15 hours video
Price
From $1199
From $999
From $799
From $429

### Which iPhone is right for you?

🏆

#### Pro Performance

iPhone 15 Pro Max for ultimate performance and battery life

💰

#### Best Value

iPhone SE gives you premium features at an affordable price

⚖️

#### Balanced Choice

iPhone 15 offers premium features in a compact size